

- modules 100% configured from info.json:
added dashboard, display_string and module_name to info.json
- startapp templates changed
- login has warning notif on bad login
- added commented out imports on view.py template
- shopyo command activates manage.py commands